@@ -73,6 +73,22 @@ register_setting(
     default="",
 )
 
+register_setting(
+    name="COMMENTS_DISQUS_API_PUBLIC_KEY",
+    label=_("Disqus public key"),
+    description=_("Public key for Disqus developer API"),
+    editable=True,
+    default="",
+)
+
+register_setting(
+    name="COMMENTS_DISQUS_API_SECRET_KEY",
+    label=_("Disqus secret key"),
+    description=_("Secret key for Disqus developer API"),
+    editable=True,
+    default="",
+)
+
 register_setting(
     name="COMMENTS_DEFAULT_APPROVED",
     label=_("Auto-approve comments"),
@@ -361,6 +377,7 @@ register_setting(
     default=(
         "BLOG_BITLY_USER", "BLOG_BITLY_KEY",
         "COMMENTS_DISQUS_SHORTNAME", "COMMENTS_NUM_LATEST",
+        "COMMENTS_DISQUS_API_PUBLIC_KEY", "COMMENTS_DISQUS_API_SECRET_KEY",
         "CONTENT_MEDIA_URL", "DEV_SERVER", "FORMS_USE_HTML5",
         "GRAPPELLI_INSTALLED", "GOOGLE_ANALYTICS_ID",
         "PAGES_MENU_SHOW_ALL", "SITE_TITLE", "SITE_TAGLINE",
