@@ -1,4 +1,6 @@
 
+import os
+
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
 from django.core.urlresolvers import reverse
@@ -9,6 +11,7 @@ from django.test import TestCase
 from django.utils.html import strip_tags
 from django.contrib.sites.models import Site
 
+
 from mezzanine.blog.models import BlogPost
 from mezzanine.conf import settings, registry
 from mezzanine.conf.models import Setting
@@ -23,6 +26,7 @@ from mezzanine.generic.models import RATING_RANGE
 from mezzanine.pages.models import RichTextPage
 from mezzanine.utils.tests import run_pyflakes_for_package
 from mezzanine.utils.importing import import_dotted_path
+from mezzanine.core.templatetags.mezzanine_tags import thumbnail
 
 
 class Tests(TestCase):
@@ -367,3 +371,22 @@ class Tests(TestCase):
 
         site1.delete()
         site2.delete()
+
+    def test_thumbnail_generation(self):
+        """
+        Test that a thumbnail is created.
+        """
+        original_name = "testleaf.jpg"
+        thumbnail_name = "testleaf-24x24.jpg"
+        thumbnail_path = os.path.join(settings.MEDIA_ROOT, thumbnail_name)
+        try:
+            os.remove(thumbnail_path)
+        except OSError:
+            pass
+        thumbnail_image = thumbnail(original_name, 24, 24)
+        self.assertEqual(thumbnail_image.lstrip("/"), thumbnail_name)
+        self.assertNotEqual(0, os.path.getsize(thumbnail_path))
+        try:
+            os.remove(thumbnail_path)
+        except OSError:
+            pass
